package ORM;

import java.io.Serializable;
import java.util.Set;

/**
 * Shopping basket entity
 * @author Jakub Macoun
 */
public class Basket implements Serializable {
    private static final long serialVersionUID = 1L;
    private Long id;
    private User user;
    private Set<BasketContent> content;

    public Basket() {}
    
    public Basket(User user) {
        this.user = user;
    }
    
    public Long getId() {
        return id;
    }

    private void setId(Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        return user.getEmail().hashCode();
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Product)) {
            return false;
        }
        
        Product other = (Product) object;
        if (this.hashCode() != other.hashCode()) {
            return false;
        }
        
        return true;
    }

    @Override
    public String toString() {
        return "ORM.Basket[ id=" + id + " ]";
    }
    
    /**
     * Adds new content
     * @param product Product to add
     * @param count Number of products
     */
    public void add(Product product, int count) {
        BasketContent newContent = null;
        
        for (BasketContent bContent : getContent()) {
            if (bContent.getProduct().equals(product)) {
                newContent = bContent;
                break;
            }
        }
        
        if (newContent == null) {
            newContent = new BasketContent(product, count);
            newContent.setBasket(this);
        } else {
            newContent.setCount(newContent.getCount() + count);
        }
        
        getContent().add(newContent);
    }

    /**
     * @return the user
     */
    public User getUser() {
        return user;
    }

    /**
     * @param user the user to set
     */
    public void setUser(User user) {
        this.user = user;
    }

    /**
     * @return the content
     */
    public Set<BasketContent> getContent() {
        return content;
    }

    /**
     * @param content the content to set
     */
    public void setContent(Set<BasketContent> content) {
        this.content = content;
    }
}