package ORM;

import controllers.users.UserSessionBean;
import java.io.Serializable;
import java.util.Date;
import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;

/**
 * Product comment entity
 * @author Jakub Macoun
 */
public class Comment implements Serializable, Comparable {
    private static final long serialVersionUID = 1L;
    private Long id;
    private User author;
    private Product product;
    private Date dateTime = new Date();
    private String content;

    public Comment() {}
    
    public Comment(Product product, String content) {
        HttpServletRequest request = (HttpServletRequest) FacesContext.getCurrentInstance().getExternalContext().getRequest();
        UserSessionBean user = (UserSessionBean) request.getSession().getAttribute("user");
        
        this.author = user.getLoggedUser();
        this.product = product;
        this.content = content;
    }
    
    public Long getId() {
        return id;
    }

    private void setId(Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        return author.hashCode() + product.hashCode() + content.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Product)) {
            return false;
        }
        
        Product other = (Product) object;
        if (this.hashCode() != other.hashCode()) {
            return false;
        }
        
        return true;
    }

    @Override
    public String toString() {
        return content;
    }

    /**
     * @return the author
     */
    public User getAuthor() {
        return author;
    }

    /**
     * @param author the author to set
     */
    public void setAuthor(User author) {
        this.author = author;
    }

    /**
     * @return the product
     */
    public Product getProduct() {
        return product;
    }

    /**
     * @param product the product to set
     */
    public void setProduct(Product product) {
        this.product = product;
    }

    /**
     * @return the dateTime
     */
    public Date getDateTime() {
        return dateTime;
    }

    /**
     * @param dateTime the dateTime to set
     */
    public void setDateTime(Date dateTime) {
        this.dateTime = dateTime;
    }

    /**
     * @return the content
     */
    public String getContent() {
        return content;
    }

    /**
     * @param content the content to set
     */
    public void setContent(String content) {
        this.content = content;
    }

    @Override
    public int compareTo(Object o) {
        Comment c = (Comment) o;
        
        int lastCmp = c.dateTime.compareTo(dateTime);
        return (lastCmp != 0 ? lastCmp : c.dateTime.compareTo(dateTime));
    }

}
