package ORM;

import ORM.enums.OrderStatus;
import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * Entity of products orders
 * @author Jakub Macoun
 */
public class Order implements Serializable {
    private static final long serialVersionUID = 1L;
    private Long id;
    private Byte deliveryWay;
    private String address;
    private Double amount;
    private Date orderDate = new Date();
    private OrderStatus status = OrderStatus.RECEIVED;
    private User user;
    private Set<BasketContent> content;

    public Long getId() {
        return id;
    }

    private void setId(Long id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Order other = (Order) obj;
        if (this.id != other.id && (this.id == null || !this.id.equals(other.id))) {
            return false;
        }
        if (this.deliveryWay != other.deliveryWay && (this.deliveryWay == null || !this.deliveryWay.equals(other.deliveryWay))) {
            return false;
        }
        if ((this.address == null) ? (other.address != null) : !this.address.equals(other.address)) {
            return false;
        }
        if (this.amount != other.amount && (this.amount == null || !this.amount.equals(other.amount))) {
            return false;
        }
        if (this.orderDate != other.orderDate && (this.orderDate == null || !this.orderDate.equals(other.orderDate))) {
            return false;
        }
        if (this.status != other.status) {
            return false;
        }
        if (this.user != other.user && (this.user == null || !this.user.equals(other.user))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 29 * hash + (this.id != null ? this.id.hashCode() : 0);
        hash = 29 * hash + (this.deliveryWay != null ? this.deliveryWay.hashCode() : 0);
        hash = 29 * hash + (this.address != null ? this.address.hashCode() : 0);
        hash = 29 * hash + (this.amount != null ? this.amount.hashCode() : 0);
        hash = 29 * hash + (this.orderDate != null ? this.orderDate.hashCode() : 0);
        hash = 29 * hash + (this.status != null ? this.status.hashCode() : 0);
        hash = 29 * hash + (this.user != null ? this.user.hashCode() : 0);
        return hash;
    }

    @Override
    public String toString() {
        return "ORM.Order[ id=" + id + " ]";
    }

    /**
     * @return the deliveryWay
     */
    public byte getDeliveryWay() {
        return deliveryWay;
    }

    /**
     * @param deliveryWay the deliveryWay to set
     */
    public void setDeliveryWay(byte deliveryWay) {
        this.deliveryWay = deliveryWay;
    }

    /**
     * @return the address
     */
    public String getAddress() {
        return address;
    }

    /**
     * @param address the address to set
     */
    public void setAddress(String address) {
        this.address = address;
    }

    /**
     * @return the user
     */
    public User getUser() {
        return user;
    }

    /**
     * @param user the user to set
     */
    public void setUser(User user) {
        this.user = user;
    }

    /**
     * @return the content
     */
    public Set<BasketContent> getContent() {
        return content;
    }

    /**
     * @param content the content to set
     */
    public void setContent(Set<BasketContent> content) {
        this.content = content;
    }

    /**
     * @return the orderDate
     */
    public Date getOrderDate() {
        return orderDate;
    }

    /**
     * @param orderDate the orderDate to set
     */
    public void setOrderDate(Date orderDate) {
        this.orderDate = orderDate;
    }

    /**
     * @return the status
     */
    public OrderStatus getStatus() {
        return status;
    }

    /**
     * @param status the status to set
     */
    public void setStatus(OrderStatus status) {
        this.status = status;
    }

    /**
     * @return the amount
     */
    public double getAmount() {
        return amount;
    }

    /**
     * @param amount the amount to set
     */
    public void setAmount(double amount) {
        this.amount = amount;
    }
}
