package ORM;

import java.io.Serializable;
import java.util.*;

/**
 * Product entity
 * @author Jakub Macoun
 */
public class Product implements Serializable {
    private static final long serialVersionUID = 1L;
    private Long id;
    private String name;
    private double price;
    private String description;
    private Category category;
    private List<Comment> comments = new ArrayList<Comment>();
    private Map<Long, Rating> ratings = new HashMap<Long, Rating>();

    public Long getId() {
        return id;
    }

    private void setId(Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        StringBuilder builder = new StringBuilder();
        builder.append(name);
        builder.append(String.valueOf(price));
        builder.append(description);
        
        return builder.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Product)) {
            return false;
        }
        
        Product other = (Product) object;
        if (this.hashCode() != other.hashCode()) {
            return false;
        }
        
        return true;
    }

    @Override
    public String toString() {
        return name;
    }

    /**
     * @return the category
     */
    public Category getCategory() {
        return category;
    }

    /**
     * @param category the category to set
     */
    public void setCategory(Category category) {
        this.category = category;
    }

    /**
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return the description
     */
    public String getDescription() {
        return description;
    }
    
    /**
     * @return the description (max length 300, no BRs)
     */
    public String getShortDescription() {
        try {
            if (description instanceof String && description.length() > 300) {
                return description.replace("<br />", "").substring(0, 300) + "...";
            } else {
                return description.replace("<br />", "");
            }
        } catch (NullPointerException ex) {
            return description;
        }
    }

    /**
     * @param description the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * @return the price
     */
    public double getPrice() {
        return price;
    }

    /**
     * @param price the price to set
     */
    public void setPrice(double price) {
        this.price = price;
    }

    /**
     * @return the comments
     */
    public List<Comment> getComments() {
        return comments;
    }
    
    /**
     * @param comments the comments to set
     */
    public void setComments(List<Comment> comments) {
        this.comments = comments;
    }

    /**
     * Add comment
     * @param comment Comment to add
     */
    public void addComment(Comment comment) {
        this.comments.add(comment);
        this.comments.add(comment);
        Collections.sort(comments);
    }

    /**
     * @return the ratings
     */
    public Map<Long, Rating> getRatings() {
        return ratings;
    }

    /**
     * @param ratings the ratings to set
     */
    public void setRatings(Map<Long, Rating> ratings) {
        this.ratings = ratings;
    }
    
    /**
     * Adds rating
     * @param rating Rating to add
     */
    public void addRating(Rating rating) {
        ratings.put(rating.getUser().getId(), rating);
    }
}