package ORM;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * User entity
 * @author Jakub Macoun
 */
public class User implements Serializable {
    private static final long serialVersionUID = 1L;
    private Long id;
    private String email;
    private String name;
    private String password;
    private String address;
    private Set<Rating> ratings;
    private Basket basket;
    private Set<Order> orders;
    
    private Map<Long, Rating> ratingsMap = new HashMap<Long, Rating>();

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        try {
            return email.hashCode();
        } catch (NullPointerException ex) {
            return 0;
        }
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Product)) {
            return false;
        }
        
        Product other = (Product) object;
        if (this.hashCode() != other.hashCode()) {
            return false;
        }
        
        return true;
    }

    @Override
    public String toString() {
        return name;
    }

    /**
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name.trim();
    }

    /**
     * @return the password
     */
    public String getPassword() {
        return password;
    }

    /**
     * @param password the password to set (in hash form)
     */
    public void setPassword(String password) {
        this.password = password.trim();
    }

    /**
     * @return the email
     */
    public String getEmail() {
        return email;
    }

    /**
     * @param email the email to set
     */
    public void setEmail(String email) {
        this.email = email.trim();
    }

    /**
     * @return the ratings
     */
    public Set<Rating> getRatings() {
        return ratings;
    }

    /**
     * @param ratings the ratings to set
     */
    public void setRatings(Set<Rating> ratings) {
        this.ratings = ratings;
    }
    
    /**
     * Adds rating
     * @param rating Rating to add
     */
    public void addRating(Rating rating) {
        ratings.add(rating);
    }

    /**
     * @return the ratingsMap
     */
    public Map<Long, Rating> getRatingsMap() {
        return ratingsMap;
    }

    /**
     * @return the basket
     */
    public Basket getBasket() {
        return basket;
    }

    /**
     * @param basket the basket to set
     */
    public void setBasket(Basket basket) {
        this.basket = basket;
    }

    /**
     * @return the address
     */
    public String getAddress() {
        return address;
    }

    /**
     * @param address the address to set
     */
    public void setAddress(String address) {
        this.address = address;
    }

    /**
     * @return the orders
     */
    public Set<Order> getOrders() {
        return orders;
    }

    /**
     * @param orders the orders to set
     */
    public void setOrders(Set<Order> orders) {
        this.orders = orders;
    }
}
