package controllers.branches;

import ORM.Branch;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import org.hibernate.Query;
import org.hibernate.Session;
import util.HibernateUtil;

/**
 * Bean manages branches
 * @author Jakub Macoun
 */
@ManagedBean(name="branches")
@ApplicationScoped
public class BranchesBean implements Serializable{
    
    private Map<Long, Branch> branchMap = new HashMap<Long, Branch>();
    private Branch central;
    
    /** Creates a new instance of BranchesBean */
    public BranchesBean() {
        loadMap();
    }

    /**
     * Loads list of branches
     */
    public final void loadMap() {
        Session session = HibernateUtil.getSessionFactory().openSession();
        Query query = session.createQuery("FROM Branch ORDER BY central DESC, name");
        
        for (Branch branch : (List<Branch>) query.list()) {
            // Is central?
            if (branch.isCentral()) {
                central = branch;
            }
            
            branchMap.put(branch.getId(), branch);
        }
        
        session.close();
    }

    /**
     * @return the branchMap
     */
    public Map<Long, Branch> getBranchMap() {
        return branchMap;
    }

    /**
     * @param branchMap the branchList to set
     */
    public void setBranchList(Map<Long, Branch> branchMap) {
        this.branchMap = branchMap;
    }

    /**
     * @return the central
     */
    public Branch getCentral() {
        return central;
    }

    /**
     * @param central the central to set
     */
    public void setCentral(Branch central) {
        this.central = central;
    }
}
