package controllers.products;

import ORM.Basket;
import ORM.BasketContent;
import ORM.Product;
import controllers.users.UserSessionBean;
import helpers.Navigator;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import org.hibernate.Transaction;
import util.HibernateUtil;

/**
 * Bean handles basket
 * @author Jakub Macoun
 */
@ManagedBean(name="basket")
@RequestScoped
public class BasketBean {

    @ManagedProperty(value="#{user}")
    private UserSessionBean userBean;
    private int countToAdd = 1;
    private BasketContent selectedContent;
    
    /** Creates a new instance of BasketBean */
    public BasketBean() {
    }
    
    /**
     * Adds the product to users basket
     */
    public void add() {
        if (!userBean.isLogged()) {
            return;
        }
        
        Product product = userBean.getViewedProduct();
        Basket basket = userBean.getLoggedUser().getBasket();
        basket.add(product, countToAdd);
        
        Transaction transaction = userBean.getHibernate().beginTransaction();
        userBean.getHibernate().update(basket);
        transaction.commit();

        userBean.loadBasket();
    }
    
    /**
     * Redirects to order page
     */
    public void goToOrder() {
        Navigator.redirect("/user/basket/order");
    }
    
    /**
     * Redirect to product info page
     */
    public void showProductInfo() {
        Navigator.redirect("/products/" + selectedContent.getProduct().getId());
    }
    
    /**
     * Removes selected product from basket
     */
    public void removeProduct() {
        Basket basket = userBean.getLoggedUser().getBasket();
        basket.getContent().remove(selectedContent);
        userBean.getBasketContent().remove(selectedContent);
        
        Transaction transaction = userBean.getHibernate().beginTransaction();
        userBean.getHibernate().save(basket);
        userBean.getHibernate().delete(selectedContent);
        transaction.commit();

        userBean.setBasketItemsCount(userBean.getBasketItemsCount() - 1);
    }

    /**
     * @return the countToAdd
     */
    public int getCountToAdd() {
        return countToAdd;
    }

    /**
     * @param countToAdd the countToAdd to set
     */
    public void setCountToAdd(int countToAdd) {
        this.countToAdd = countToAdd;
    }

    /**
     * @param userBean the userBean to set
     */
    public void setUserBean(UserSessionBean userBean) {
        this.userBean = userBean;
    }

    /**
     * @return the selectedContent
     */
    public BasketContent getSelectedContent() {
        return selectedContent;
    }

    /**
     * @param selectedContent the selectedContent to set
     */
    public void setSelectedContent(BasketContent selectedContent) {
        this.selectedContent = selectedContent;
    }

    
}
