package controllers.products;

import ORM.Comment;
import controllers.users.UserSessionBean;
import helpers.BeansManager;
import java.util.Collections;
import java.util.List;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import org.hibernate.Query;
import org.hibernate.Transaction;
import util.HibernateUtil;

/**
 * Bean to manage products comments
 * @author Jakub Macoun
 */
@ManagedBean(name="comments")
@RequestScoped
public class CommentsBean {

    @ManagedProperty(value="#{user}")
    private UserSessionBean userBean;
    private String commentToAdd;
    
    /** Creates a new instance of CommentsBean */
    public CommentsBean() {
    }
    
    /**
     * Add a comment with text in commentToAdd
     */
    public void doComment() {
        UserSessionBean user = (UserSessionBean) BeansManager.getSessionScoped("user");
        
        if (!user.isLogged()) {
            return;
        }
        
        Comment comment = new Comment(userBean.getViewedProduct(), getCommentToAdd());
        userBean.getViewedProduct().addComment(comment);
        
        Transaction transaction = userBean.getHibernate().beginTransaction();
        userBean.getHibernate().save(comment);
        transaction.commit();

        setCommentToAdd(null);
    }
    
    /**
     * Get list of last comments
     * @param number Number of comments to get
     * @return List of last comments
     */
    public List<Comment> getLastComments(int number) {
        Query query = userBean.getHibernate().createQuery("FROM Comment");
        query.setMaxResults(number);
        
        List<Comment> list = query.list();
        Collections.sort(list);
        return list;
    }

    /**
     * @return the commentToAdd
     */
    public String getCommentToAdd() {
        return commentToAdd;
    }

    /**
     * @param commentToAdd the commentToAdd to set
     */
    public void setCommentToAdd(String commentToAdd) {
        this.commentToAdd = commentToAdd;
    }

    /**
     * @param userBean the userBean to set
     */
    public void setUserBean(UserSessionBean userBean) {
        this.userBean = userBean;
    }
}
