package controllers.products;

import ORM.Product;
import ORM.Rating;
import controllers.users.UserSessionBean;
import helpers.BeansManager;
import helpers.Messager;
import helpers.RequestDataManager;
import helpers.Texter;
import java.util.Map;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;

/**
 *
 * @author Jakub Macoun
 */
@ManagedBean(name="productInfo")
@RequestScoped
public class ProductInfoBean {

    private Product info;
    
    /** Creates a new instance of ProductInfoBean */
    public ProductInfoBean() {
        getProductById();
    }
    
    /**
     * Get product by GET parameter "id"
     * @return The product or null if the product was not found
     */
    private void getProductById() {
        ProductsBean productsBean = (ProductsBean) BeansManager.getApplicationScoped("products");
        UserSessionBean userBean = (UserSessionBean) BeansManager.getSessionScoped("user");

        try {
            info = productsBean.getProductsMap().get(Long.valueOf(RequestDataManager.get("id")));
        } catch (NullPointerException ex) {
            Messager.addError("product_data", Texter.get("messages", "productNotFound"));
            return;
        }
        
        userBean.setViewedProduct(info);
    }
    
    /**
     * Counts current product rating
     */
    public double getRating() {
        int ratingCount = info.getRatings().size();
        int ratingSum = 0;
        double rating;
        
        for (Map.Entry<Long, Rating> entry : info.getRatings().entrySet()) {
            if (entry.getValue().getPoints() == 0) {
                ratingCount--;
                continue;
            }
            ratingSum += entry.getValue().getPoints();
        }
        
        try {
            rating = ratingSum / ratingCount;
        } catch (ArithmeticException ex) {
            rating = 0;
        }

        return rating;
    }

    /**
     * @return the userRating
     */
    public double getUserRating() {
        UserSessionBean userBean = (UserSessionBean) BeansManager.getSessionScoped("user");
        Long userId = null;
        double userRating;
        try {
            userId = userBean.getLoggedUser().getId();
        } catch (NullPointerException ex) {}
        
        try {
            userRating = info.getRatings().get(userId).getPoints();
        } catch (NullPointerException ex) {
            userRating = 0;
        }

        return userRating;
    }

    /**
     * @return the info
     */
    public Product getInfo() {
        return info;
    }
    
    public void setRating(double rating) {}
    public void setUserRating(double userRating) {}
}
