package controllers.products;

import ORM.Product;
import ORM.Rating;
import ORM.User;
import controllers.users.UserSessionBean;
import helpers.BeansManager;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import org.hibernate.Transaction;
import org.primefaces.event.RateEvent;

/**
 * Products rating bean
 * @author Jakub Macoun
 */
@ManagedBean(name="productRating")
@RequestScoped
public class ProductRatingBean {
    
    @ManagedProperty(value="#{user}")
    private UserSessionBean userBean;
    
    /** Creates a new instance of ProductRatingBean */
    public ProductRatingBean() {
    }
    
    /**
     * Do the rating
     */
    public void rate(RateEvent rateEvent) {
        Product product;
        User loggedUser;

        try {
            UserSessionBean userBean = (UserSessionBean) BeansManager.getSessionScoped("user");
            loggedUser = userBean.getLoggedUser();
            product = userBean.getViewedProduct();
        } catch (NullPointerException ex) {
            return;
        }

        if (!(product instanceof Product) || !(loggedUser instanceof User)) {
            return;
        }

        // Get already existing rating
        Rating rating = null;
        for (Rating testedRating : loggedUser.getRatings()) {
            if (testedRating.getProduct().equals(product)) {
                rating = (Rating) userBean.getHibernate().get(Rating.class, testedRating.getId());
                break;
            }
        }

        // Set points or create Rating instance
        if (rating == null) {
            rating = new Rating(product, loggedUser, (Double) rateEvent.getRating());
            
            loggedUser.addRating(rating);
            product.addRating(rating);
        } else {
            rating.setPoints((Double) rateEvent.getRating());
        }
        
        // Save
        Transaction transaction = userBean.getHibernate().beginTransaction();
        userBean.getHibernate().saveOrUpdate(rating);
        transaction.commit();
    }
}