package controllers.products;

import ORM.Category;
import ORM.Product;
import java.util.*;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import org.hibernate.Query;
import org.hibernate.Session;
import org.primefaces.component.menuitem.MenuItem;
import org.primefaces.component.submenu.Submenu;
import org.primefaces.model.DefaultMenuModel;
import org.primefaces.model.MenuModel;
import util.HibernateUtil;

/**
 * Bean to manage products and their cateogires
 * @author Jakub Macoun
 */
@ManagedBean(name="products")
@ApplicationScoped
public class ProductsBean {

    private MenuModel menuModel = new DefaultMenuModel();
    private Map<Long, Product> productsMap = new HashMap<Long, Product>();
    private List<Product> productsList = new ArrayList<Product>();
    private List<Product> randomProductsList;
    private String searchValue;
    
    /** Creates a new instance of ProductsBean */
    public ProductsBean() {
        initMenuModel();
    }
    
    /**
     * Initializes products list
     */
    public final void initMenuModel() {
        MenuItem item;
        Submenu submenu;
        Query query;
        Set<Product> products;
        
        // Categories
        Session session = HibernateUtil.getSessionFactory().openSession();
        query = session.createQuery("FROM Category ORDER BY name");
        List<Category> categories = (List<Category>) query.list();
        for (Category category : categories) {
            products = category.getProducts();
            if (products.isEmpty()) {
                continue;
            }
            
            // Category
            submenu = new Submenu();
            submenu.setLabel(category.getName());
            
            // Products
            for (Product product : products) {
                item = new MenuItem();
                item.setValue(product.getName());
                item.setUrl("/products/" + product.getId());
                submenu.getChildren().add(item);
                
                // Add to complete products list
                productsMap.put(product.getId(), product);
            }
            
            menuModel.addSubmenu(submenu);
            productsList = new ArrayList<Product>(productsMap.values());
            randomProductsList = new ArrayList<Product>(productsMap.values());

        }
        
        session.close();
    }
    
    /**
     * Method for product search autocomplete
     * @param query Query from autocomplete input
     * @return List of suitable results
     */
    public List<String> autocompleteSearch(String query) {
        List<String> results = new ArrayList<String>();

        for (Map.Entry<Long, Product> product : productsMap.entrySet()) {
            if (product.getValue().getName().toLowerCase().matches("^.*" + query.toLowerCase() + ".*$")) {
                results.add(product.getValue().getName());
            }
        }
        
        return results;
    }
    
    /**
     * Create list of random products
     * @param count Number of products in random list
     * @return List with random products
     */
    public List<Product> getRandomProducts(int count) {
        List<Product> finalRandomList = new ArrayList<Product>();
        try {
            Collections.shuffle(randomProductsList);
        } catch (NullPointerException ex) {
            return finalRandomList;
        }
        
        // Low count of products
        if (count >= randomProductsList.size()) {
            return randomProductsList;
        }
        
        for (int i = 0; i < count; i++) {
            finalRandomList.add(randomProductsList.get(i));
        }
        
        return finalRandomList;
    }

    /**
     * @return the menuModel
     */
    public MenuModel getMenuModel() {
        return menuModel;
    }

    /**
     * @return the productsList
     */
    public Map<Long, Product> getProductsMap() {
        return productsMap;
    }

    /**
     * @return the searchValue
     */
    public String getSearchValue() {
        return searchValue;
    }

    /**
     * @param searchValue the searchValue to set
     */
    public void setSearchValue(String searchValue) {
        this.searchValue = searchValue;
    }

    /**
     * @return the productsList
     */
    public List<Product> getProductsList() {
        return productsList;
    }
}
