package controllers.site;

import ORM.Branch;
import controllers.branches.BranchesBean;
import controllers.users.UserSessionBean;
import helpers.BeansManager;
import helpers.Texter;
import java.io.Serializable;
import java.util.Map;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.SessionScoped;
import org.primefaces.component.menuitem.MenuItem;
import org.primefaces.component.submenu.Submenu;
import org.primefaces.model.DefaultMenuModel;
import org.primefaces.model.MenuModel;

/**
 * Bean to manage menus
 * @author Jakub Macoun
 */
@ManagedBean(name = "menu")
@SessionScoped
public class MenuBean implements Serializable {

    @ManagedProperty(value="#{branches}")
    private BranchesBean branches;
    private MenuModel mainMenu;
    
    /**
     * Creates a new instance of MenuBean
     */
    public MenuBean() {
        initMainMenu();
    }
    
    /**
     * Initializes main menu model
     */
    public final void initMainMenu() {
        Submenu submenu;
        MenuItem item;
        mainMenu = new DefaultMenuModel();
        UserSessionBean user = (UserSessionBean) BeansManager.getSessionScoped("user");
        
        // Info
        submenu = new Submenu();
        submenu.setLabel(Texter.get("menu", "information"));
        
        // About
        item = new MenuItem();
        item.setValue(Texter.get("menu", "about"));
        item.setUrl("/about");
        submenu.getChildren().add(item);
        
        // Contact
        Long centralId = null;
        try {
            centralId = branches.getCentral().getId();
        } catch (NullPointerException ex) {}
        
        item = new MenuItem();
        item.setValue(Texter.get("menu", "contact"));
        item.setUrl("/branches/" + centralId);
        submenu.getChildren().add(item);
        mainMenu.addSubmenu(submenu);
        
        // Branches
        submenu = new Submenu();
        submenu.setLabel(Texter.get("menu", "branches"));
        
        try {
            for(Map.Entry<Long, Branch> branchEntry : branches.getBranchMap().entrySet()) {
                Branch branch = branchEntry.getValue();
                
                item = new MenuItem();
                item.setValue(branch.getName());
                item.setUrl("/branches/" + branch.getId());
                submenu.getChildren().add(item);
            }
        } catch (NullPointerException ex) {}
        
        mainMenu.addSubmenu(submenu);
        
        // Support
        item = new MenuItem();
        item.setValue(Texter.get("menu", "support"));
        item.setUrl("/support");
        mainMenu.addMenuItem(item);

        // User
        if (user instanceof UserSessionBean && user.isLogged()) {
            submenu = new Submenu();
            submenu.setLabel(Texter.get("menu", "userSection"));
            
            // Settings
            item = new MenuItem();
            item.setValue(Texter.get("menu", "settings"));
            item.setUrl("/user/settings");
            submenu.getChildren().add(item);
            
            // Orders
            item = new MenuItem();
            item.setValue(Texter.get("menu", "orderList"));
            item.setUrl("/user/orders");
            submenu.getChildren().add(item);
            mainMenu.addSubmenu(submenu);
        }
    }

    /**
     * @return the mainMenu
     */
    public MenuModel getMainMenu() {
        return mainMenu;
    }

    /**
     * @return the branches
     */
    public BranchesBean getBranches() {
        return branches;
    }

    /**
     * @param branches the branches to set
     */
    public void setBranches(BranchesBean branches) {
        this.branches = branches;
    }
}
