package controllers.users;

import ORM.BasketContent;
import ORM.Order;
import ORM.enums.OrderStatus;
import helpers.Navigator;
import java.util.List;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.SessionScoped;
import org.hibernate.Query;
import org.hibernate.Transaction;

/**
 * Bean to manage order
 * @author Jakub Macoun
 */
@ManagedBean(name="order")
@SessionScoped
public class OrderBean {

    private static final byte ORDER_WAY_POST = 0;
    private static final byte ORDER_WAY_PICKUP = 1;
    
    @ManagedProperty(value="#{user}")
    private UserSessionBean userBean;
    private byte deliveryWay;
    private String address;
    
    
    /** Creates a new instance of OrderBean */
    public OrderBean() {
    }
    
    /**
     * Sends current order
     */
    public void send() {
        if (userBean.getBasketItemsCount() == 0) {
            return;
        }
        
        Order order = new Order();
        order.setAddress(address);
        order.setDeliveryWay(deliveryWay);
        order.setUser(userBean.getLoggedUser());
        order.setStatus(OrderStatus.FINISHED);
        order.setAmount(userBean.getBasketPriceSum());
        
        Transaction transaction = userBean.getHibernate().beginTransaction();
        
        // Transform content from basket to order
        for (BasketContent basketContent : userBean.getLoggedUser().getBasket().getContent()) {
            basketContent.setBasket(null);
            basketContent.setTheOrder(order);
            userBean.getHibernate().update(basketContent);
        }
        
        userBean.getHibernate().save(order);
        transaction.commit();
        
        // Empty the basket
        userBean.getLoggedUser().getBasket().getContent().clear();
        userBean.getBasketContent().clear();
        
        // Finish
        userBean.setBasketItemsCount(0);
        userBean.setBasketCountSum(0);
        userBean.setBasketPriceSum(0);
                
        Navigator.redirect("/user/order/done");
    }

    /**
     * Get users order list
     * @return Order list
     */
    public List<Order> getOrderList() {
        Query query = userBean.getHibernate().createQuery("FROM Order WHERE user = :user");
        query.setParameter("user", userBean.getLoggedUser());
        return (List<Order>) query.list();
    }
    
    /**
     * @param userBean the userBean to set
     */
    public void setUserBean(UserSessionBean userBean) {
        this.userBean = userBean;
        address = userBean.getLoggedUser().getAddress();
    }

    /**
     * @return the ORDER_WAY_POST
     */
    public byte getORDER_WAY_POST() {
        return ORDER_WAY_POST;
    }

    /**
     * @return the ORDER_WAY_PICKUP
     */
    public byte getORDER_WAY_PICKUP() {
        return ORDER_WAY_PICKUP;
    }

    /**
     * @return the deliveryWay
     */
    public byte getDeliveryWay() {
        return deliveryWay;
    }

    /**
     * @param deliveryWay the deliveryWay to set
     */
    public void setDeliveryWay(byte deliveryWay) {
        this.deliveryWay = deliveryWay;
    }

    /**
     * @return the address
     */
    public String getAddress() {
        return address;
    }

    /**
     * @param address the address to set
     */
    public void setAddress(String address) {
        this.address = address;
    }

}
