package controllers.users;

import ORM.Basket;
import ORM.User;
import helpers.Hasher;
import helpers.Messager;
import helpers.Texter;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import org.hibernate.Query;
import org.hibernate.Transaction;
import util.HibernateUtil;

/**
 * New user registry controller
 * @author Jakub Macoun
 */
@ManagedBean(name="userRegistry")
@RequestScoped
public class UserRegistryBean {
    
    @ManagedProperty(value="#{user}")
    private UserSessionBean userSession;
    
    private User newUser = new User();

    /**
     * Creates a new instance of UserRegistryBean
     */
    public UserRegistryBean() {
    }
    
    /**
     * Registers new user
     * @return Navigation
     */
    public void register() {
        Transaction transaction = userSession.getHibernate().beginTransaction();
        
        // Check for duplicated e-mail
        Query query = userSession.getHibernate().createQuery("FROM User WHERE email = :email");
        query.setParameter("email", newUser.getEmail());
        if (query.list().size() > 0) {
            Messager.addError("registration:email", Texter.get("messages", "emailDuplicated"));
            return;
        }
        
        // Create basket
        Basket basket = new Basket(newUser);
        
        // Create user
        newUser.setPassword(Hasher.sha512(newUser.getPassword()));
        userSession.getHibernate().save(newUser);
        userSession.getHibernate().save(basket);
        transaction.commit();
        
        // Finish
        newUser = new User();
        Messager.addInfo(Texter.get("texts", "registrationSuccess"));
    }

    /**
     * @return the newUser
     */
    public User getNewUser() {
        return newUser;
    }

    /**
     * @param newUser the newUser to set
     */
    public void setNewUser(User newUser) {
        this.newUser = newUser;
    }

    /**
     * @param userSession the userSession to set
     */
    public void setUserSession(UserSessionBean userSession) {
        this.userSession = userSession;
    }
}
